@@ -29,9 +29,14 @@ class Constant(object):
     cm_inv_to_ev = 0.00012398  # cm^-1 to eV
     ry_bohr_to_eV_A = 25.71104309541616  # or RYDBERG / BOHR
 
-
 GENERAL_REGEX = Munch()
 GENERAL_REGEX.update({
     'double_number': r'[-+]?\d*\.\d+(?:[eE][-+]?\d+)?',
     'int_number': r'[+-]?\d+'
 })
+
+ASE_FORMATS = {
+    "poscar": "vasp",
+    "cif": "cif",
+    "espresso-in": "espresso-in"
+}
