@@ -1,5 +1,5 @@
 import os
-
+from express.parsers.settings import ASE_FORMATS
 
 def find_file(name, path):
     """
@@ -60,3 +60,17 @@ def lattice_basis_to_poscar(lattice, basis, basis_units="cartesian"):
         basis_units,
         "\n".join([" ".join(["{0:14.9f}".format(v) for v in x["value"]]) for x in basis["coordinates"]])
     ])
+
+def convert_to_ase_format(format):
+    """
+    Function converts the format keywords used in this code to their
+    corresponding ase keywords based on a predisposed dictionary of values.
+
+    Returns:
+        Str
+
+    Example:
+        format="poscar" --> format="vasp"
+    """
+    ase_format = ASE_FORMATS[format]
+    return ase_format
